# Plotting API
The main user-facing functions are:

- `iplotx.network`to visualise networks/graphs and graph groupings (covers and clusterings)
- `iplotx.tree` to visualise trees.

```{tip}
  `iplotx.plot` and `iplotx.graph` are synonyms for `iplotx.network`.
```

```{warning}
  `iplotx.plot` is deprecated and will be removed in future versions. Please use `iplotx.network` instead.
```

```{eval-rst}
.. autofunction:: iplotx.network

.. autofunction:: iplotx.tree
